pecos.error\_models.error\_depolar
==================================

.. automodule:: pecos.error_models.error_depolar











   .. rubric:: Classes

   .. autosummary::

      DepolarizingErrorModel
